package com.ruoyi.ems.service;

import com.ruoyi.ems.domain.OpAlarmPolicy;

import java.util.List;

/**
 * 能源设施告警策略Service接口
 *
 * @author ruoyi
 * @date 2024-08-26
 */
public interface IAdmOpAlarmPolicyService {
    /**
     * 查询能源设施告警策略
     *
     * @param id 能源设施告警策略主键
     * @return 能源设施告警策略
     */
    OpAlarmPolicy selectAdmOpAlarmPolicyById(Long id);

    /**
     * 查询能源设施告警策略列表
     *
     * @param opAlarmPolicy 能源设施告警策略
     * @return 能源设施告警策略集合
     */
    List<OpAlarmPolicy> selectAdmOpAlarmPolicyList(OpAlarmPolicy opAlarmPolicy);

    /**
     * 新增能源设施告警策略
     *
     * @param opAlarmPolicy 能源设施告警策略
     * @return 结果
     */
    int insertAdmOpAlarmPolicy(OpAlarmPolicy opAlarmPolicy);

    /**
     * 修改能源设施告警策略
     *
     * @param opAlarmPolicy 能源设施告警策略
     * @return 结果
     */
    int updateAdmOpAlarmPolicy(OpAlarmPolicy opAlarmPolicy);

    /**
     * 批量删除能源设施告警策略
     *
     * @param ids 需要删除的能源设施告警策略主键集合
     * @return 结果
     */
    int deleteAdmOpAlarmPolicyByIds(Long[] ids);

    /**
     * 删除能源设施告警策略信息
     *
     * @param id 能源设施告警策略主键
     * @return 结果
     */
    int deleteAdmOpAlarmPolicyById(Long id);
}
